@@ -1,5 +1,5 @@
 /*********************************************************
- * Copyright (C) 1998-2020 VMware, Inc. All rights reserved.
+ * Copyright (c) 1998-2022 VMware, Inc. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published
@@ -1568,6 +1568,34 @@ TOOLS_VERSION_UINT_TO_COMPONENTS(const ToolsVersion toolsVersion,   // IN
 #define   TOOLS_VERSION_JACKHAMMER_PATCH8_V_MNR  3
 #define   TOOLS_VERSION_JACKHAMMER_PATCH8_V_BASE 21
 
+#ifndef RC_INVOKED
+#define   TOOLS_VERSION_JACKHAMMER_PATCH9 TOOLS_VERSION_TO_UINT(TOOLS_VERSION_JACKHAMMER_PATCH9_V)
+#endif /* RC_INVOKED */
+#define   TOOLS_VERSION_JACKHAMMER_PATCH9_V_MJR  10
+#define   TOOLS_VERSION_JACKHAMMER_PATCH9_V_MNR  3
+#define   TOOLS_VERSION_JACKHAMMER_PATCH9_V_BASE 22
+
+#ifndef RC_INVOKED
+#define   TOOLS_VERSION_JACKHAMMER_PATCH10 TOOLS_VERSION_TO_UINT(TOOLS_VERSION_JACKHAMMER_PATCH10_V)
+#endif /* RC_INVOKED */
+#define   TOOLS_VERSION_JACKHAMMER_PATCH10_V_MJR  10
+#define   TOOLS_VERSION_JACKHAMMER_PATCH10_V_MNR  3
+#define   TOOLS_VERSION_JACKHAMMER_PATCH10_V_BASE 23
+
+#ifndef RC_INVOKED
+#define   TOOLS_VERSION_JACKHAMMER_PATCH11 TOOLS_VERSION_TO_UINT(TOOLS_VERSION_JACKHAMMER_PATCH11_V)
+#endif /* RC_INVOKED */
+#define   TOOLS_VERSION_JACKHAMMER_PATCH11_V_MJR  10
+#define   TOOLS_VERSION_JACKHAMMER_PATCH11_V_MNR  3
+#define   TOOLS_VERSION_JACKHAMMER_PATCH11_V_BASE 24
+
+#ifndef RC_INVOKED
+#define   TOOLS_VERSION_JACKHAMMER_PATCH12 TOOLS_VERSION_TO_UINT(TOOLS_VERSION_JACKHAMMER_PATCH12_V)
+#endif /* RC_INVOKED */
+#define   TOOLS_VERSION_JACKHAMMER_PATCH12_V_MJR  10
+#define   TOOLS_VERSION_JACKHAMMER_PATCH12_V_MNR  3
+#define   TOOLS_VERSION_JACKHAMMER_PATCH12_V_BASE 25
+
 #ifndef RC_INVOKED
 #define   TOOLS_VERSION_SLEDGEHAMMER_RELEASE TOOLS_VERSION_TO_UINT(TOOLS_VERSION_SLEDGEHAMMER_RELEASE_V)
 #endif /* RC_INVOKED */
@@ -1589,6 +1617,13 @@ TOOLS_VERSION_UINT_TO_COMPONENTS(const ToolsVersion toolsVersion,   // IN
 #define   TOOLS_VERSION_SLEDGEHAMMER_UPDATE1_V_MNR  0
 #define   TOOLS_VERSION_SLEDGEHAMMER_UPDATE1_V_BASE 5
 
+#ifndef RC_INVOKED
+#define   TOOLS_VERSION_SLEDGEHAMMER_PATCH2 TOOLS_VERSION_TO_UINT(TOOLS_VERSION_SLEDGEHAMMER_PATCH2_V)
+#endif /* RC_INVOKED */
+#define   TOOLS_VERSION_SLEDGEHAMMER_PATCH2_V_MJR  11
+#define   TOOLS_VERSION_SLEDGEHAMMER_PATCH2_V_MNR  0
+#define   TOOLS_VERSION_SLEDGEHAMMER_PATCH2_V_BASE 6
+
 #ifndef RC_INVOKED
 #define   TOOLS_VERSION_BALLPEENHAMMER_RELEASE TOOLS_VERSION_TO_UINT(TOOLS_VERSION_BALLPEENHAMMER_RELEASE_V)
 #endif /* RC_INVOKED */
@@ -1610,9 +1645,79 @@ TOOLS_VERSION_UINT_TO_COMPONENTS(const ToolsVersion toolsVersion,   // IN
 #define   TOOLS_VERSION_BALLPEENHAMMER_UPDATE1_V_MNR  1
 #define   TOOLS_VERSION_BALLPEENHAMMER_UPDATE1_V_BASE 5
 
-#define   TOOLS_VERSION_CURRENT        TOOLS_VERSION_BALLPEENHAMMER_UPDATE1
-#define   TOOLS_VERSION_CURRENT_STR    TOOLS_VERSION_TO_STR(TOOLS_VERSION_BALLPEENHAMMER_UPDATE1)
-#define   TOOLS_VERSION_CURRENT_CSV    TOOLS_VERSION_TO_CSV(TOOLS_VERSION_BALLPEENHAMMER_UPDATE1)
+#ifndef RC_INVOKED
+#define   TOOLS_VERSION_BALLPEENHAMMER_PATCH2 TOOLS_VERSION_TO_UINT(TOOLS_VERSION_BALLPEENHAMMER_PATCH2_V)
+#endif /* RC_INVOKED */
+#define   TOOLS_VERSION_BALLPEENHAMMER_PATCH2_V_MJR  11
+#define   TOOLS_VERSION_BALLPEENHAMMER_PATCH2_V_MNR  1
+#define   TOOLS_VERSION_BALLPEENHAMMER_PATCH2_V_BASE 6
+
+#ifndef RC_INVOKED
+#define   TOOLS_VERSION_CRESCENT_WRENCH_RELEASE TOOLS_VERSION_TO_UINT(TOOLS_VERSION_CRESCENT_WRENCH_RELEASE_V)
+#endif /* RC_INVOKED */
+#define   TOOLS_VERSION_CRESCENT_WRENCH_RELEASE_V_MJR  11
+#define   TOOLS_VERSION_CRESCENT_WRENCH_RELEASE_V_MNR  2
+#define   TOOLS_VERSION_CRESCENT_WRENCH_RELEASE_V_BASE 0
+
+#ifndef RC_INVOKED
+#define   TOOLS_VERSION_CRESCENT_WRENCH_PATCH1 TOOLS_VERSION_TO_UINT(TOOLS_VERSION_CRESCENT_WRENCH_PATCH1_V)
+#endif /* RC_INVOKED */
+#define   TOOLS_VERSION_CRESCENT_WRENCH_PATCH1_V_MJR  11
+#define   TOOLS_VERSION_CRESCENT_WRENCH_PATCH1_V_MNR  2
+#define   TOOLS_VERSION_CRESCENT_WRENCH_PATCH1_V_BASE 1
+
+#ifndef RC_INVOKED
+#define   TOOLS_VERSION_CRESCENT_WRENCH_UPDATE1 TOOLS_VERSION_TO_UINT(TOOLS_VERSION_CRESCENT_WRENCH_UPDATE1_V)
+#endif /* RC_INVOKED */
+#define   TOOLS_VERSION_CRESCENT_WRENCH_UPDATE1_V_MJR  11
+#define   TOOLS_VERSION_CRESCENT_WRENCH_UPDATE1_V_MNR  2
+#define   TOOLS_VERSION_CRESCENT_WRENCH_UPDATE1_V_BASE 5
+
+#ifndef RC_INVOKED
+#define   TOOLS_VERSION_CRESCENT_WRENCH_PATCH2 TOOLS_VERSION_TO_UINT(TOOLS_VERSION_CRESCENT_WRENCH_PATCH2_V)
+#endif /* RC_INVOKED */
+#define   TOOLS_VERSION_CRESCENT_WRENCH_PATCH2_V_MJR  11
+#define   TOOLS_VERSION_CRESCENT_WRENCH_PATCH2_V_MNR  2
+#define   TOOLS_VERSION_CRESCENT_WRENCH_PATCH2_V_BASE 6
+
+#ifndef RC_INVOKED
+#define   TOOLS_VERSION_JIGSAW_RELEASE TOOLS_VERSION_TO_UINT(TOOLS_VERSION_JIGSAW_RELEASE_V)
+#endif /* RC_INVOKED */
+#define   TOOLS_VERSION_JIGSAW_RELEASE_V_MJR  11
+#define   TOOLS_VERSION_JIGSAW_RELEASE_V_MNR  3
+#define   TOOLS_VERSION_JIGSAW_RELEASE_V_BASE 0
+
+#ifndef RC_INVOKED
+#define   TOOLS_VERSION_JIGSAW_UPDATE1 TOOLS_VERSION_TO_UINT(TOOLS_VERSION_JIGSAW_UPDATE1_V)
+#endif /* RC_INVOKED */
+#define   TOOLS_VERSION_JIGSAW_UPDATE1_V_MJR  11
+#define   TOOLS_VERSION_JIGSAW_UPDATE1_V_MNR  3
+#define   TOOLS_VERSION_JIGSAW_UPDATE1_V_BASE 5
+
+#ifndef RC_INVOKED
+#define   TOOLS_VERSION_SABRE_SAW_RELEASE TOOLS_VERSION_TO_UINT(TOOLS_VERSION_SABRE_SAW_RELEASE_V)
+#endif /* RC_INVOKED */
+#define   TOOLS_VERSION_SABRE_SAW_RELEASE_V_MJR  12
+#define   TOOLS_VERSION_SABRE_SAW_RELEASE_V_MNR  0
+#define   TOOLS_VERSION_SABRE_SAW_RELEASE_V_BASE 0
+
+#ifndef RC_INVOKED
+#define   TOOLS_VERSION_SABRE_SAW_UPDATE1 TOOLS_VERSION_TO_UINT(TOOLS_VERSION_SABRE_SAW_UPDATE1_V)
+#endif /* RC_INVOKED */
+#define   TOOLS_VERSION_SABRE_SAW_UPDATE1_V_MJR  12
+#define   TOOLS_VERSION_SABRE_SAW_UPDATE1_V_MNR  0
+#define   TOOLS_VERSION_SABRE_SAW_UPDATE1_V_BASE 5
+
+#ifndef RC_INVOKED
+#define   TOOLS_VERSION_NEXT TOOLS_VERSION_TO_UINT(TOOLS_VERSION_NEXT_V)
+#endif /* RC_INVOKED */
+#define   TOOLS_VERSION_NEXT_V_MJR  12
+#define   TOOLS_VERSION_NEXT_V_MNR  1
+#define   TOOLS_VERSION_NEXT_V_BASE 0
+
+#define   TOOLS_VERSION_CURRENT        TOOLS_VERSION_NEXT
+#define   TOOLS_VERSION_CURRENT_STR    TOOLS_VERSION_TO_STR(TOOLS_VERSION_NEXT)
+#define   TOOLS_VERSION_CURRENT_CSV    TOOLS_VERSION_TO_CSV(TOOLS_VERSION_NEXT)
 
 /*
  * The extended Tools version is the current Tools version with the
